build_P_matrix: Construct Penalty Matrix

View source: R/pclm_fit.R

build_P_matrixR Documentation

Construct Penalty Matrix

Description

Construct Penalty Matrix

Usage

build_P_matrix(BA, BY, lambda, type)

Arguments

BA

B-spline basis object for age axis

BY

B-spline basis object for year axis

lambda

Smoothing parameter to be used in pclm estimation. If lambda = NA an algorithm will find the optimal values. pclm takes a single value. pclm2D takes two, one for the age axis and one for the year axis, and either may be NA to be found by optimisation while the other is held fixed.

type

Type of PCLM model. Options: "1D", "2D" for univariate and two-dimensional model respectively.


ungroup documentation built on Oct. 3, 2026, 5:06 p.m.