delete.artificial.bin: Delete from results the last group added artificially in pclm...

View source: R/pclm_fit.R

delete.artificial.binR Documentation

Delete from results the last group added artificially in pclm and pclm2D

Description

Delete from results the last group added artificially in pclm and pclm2D

Usage

delete.artificial.bin(M)

Arguments

M

A pclm.fit object


ungroup documentation built on Oct. 3, 2026, 5:06 p.m.