pclm.input.check: Validate input values

View source: R/utils.R

pclm.input.checkR Documentation

Validate input values

Description

Validate input values

Usage

pclm.input.check(X, pclm.type)

Arguments

X

A list with input arguments provided in pclm function

pclm.type

Either "1D" or "2D". Selects which shape rules apply to y and how many smoothing parameters are expected.


ungroup documentation built on Oct. 3, 2026, 5:06 p.m.