The generic plot for a pclm2D object is constructed using
persp method.
Arguments
- x
an object of class
pclm2D.- type
chart type. Defines which data are plotted,
"fitted"values or"observed"input data. Default:"fitted".- colors
Colors to interpolate for the surface palette; must be a valid argument to
colorRampPalette. Default:c("#b6e3db", "#e5d9c2", "#b5ba61", "#725428").- nbcol
dimension of the color palette. Number of colors. Default: 25.
- xlab, ylab, zlab
titles for the axes. N.B. These must be character strings; expressions are not accepted. Numbers will be coerced to character strings.
- theta, phi
angles defining the viewing direction.
thetagives the azimuthal direction andphithe colatitude.- border
the color of the line drawn around the surface facets. The default,
NULL, corresponds topar("fg"). A value ofNAwill disable the drawing of borders: this is sometimes useful when the surface is shaded.- ticktype
character:
"simple"draws just an arrow parallel to the axis to indicate direction of increase;"detailed"draws normal ticks as per 2D plots.- ...
any other argument to be passed to
persp.