Skip to contents

Extract PCLM-2D Deviance Residuals

Usage

# S3 method for class 'pclm2D'
residuals(object, ...)

Arguments

object

an object for which the extraction of model residuals is meaningful.

...

other arguments.

Value

Residuals extracted from the object object.

Examples


Dx <- ungroup.data$Dx[, 1:10]

# Aggregate data to ungroup it in the example below
x      <- c(0, 1, seq(5, 85, by = 5))
nlast  <- 26
n      <- c(diff(x), nlast)
group  <- rep(x, n)
y      <- aggregate(Dx, by = list(group), FUN = "sum")[, -1]

# Example
P1 <- pclm2D(x, y, nlast)
#>    Ungrouping data      

residuals(P1)
#>                 1980        1981       1982        1983        1984        1985
#> [0,1)      81.312576   95.686239  100.20803  125.084286   86.082352  149.600160
#> [1,5)    -155.367332 -169.506678 -125.65420 -137.622218 -143.620595 -117.177123
#> [5,10)     65.887221   57.088615   50.20705   55.429327   42.893897   40.700208
#> [10,15)     2.146195   -4.142730  -34.56040  -26.059794   -6.599258  -13.142998
#> [15,20)    -9.229870   16.343544  -13.30634   16.178922  -19.835060   -4.978672
#> [20,25)    21.980314    9.421463  -40.59738   -2.500662    1.262400   -7.757827
#> [25,30)    41.107851  -24.374348    3.26980   12.634879   17.214362  -32.571806
#> [30,35)    16.932056  -26.921423  -22.80252  -45.303163  -12.083816    5.136224
#> [35,40)   -13.321378   -9.094032   92.12480    4.308084   40.294327   35.832854
#> [40,45)    19.250121  -72.244488  -48.81181  -13.194314   17.524511  -14.879096
#> [45,50)    58.724087   49.390747   10.88812  -35.887869  -67.854654  -58.397471
#> [50,55)   -23.387153  -17.166428  -18.53549   88.118484  -44.471979    8.792365
#> [55,60)    50.153325  -24.089565   18.71250 -181.609595  -56.753161   46.140846
#> [60,65)   -56.994335   54.305083  132.55193  108.555825  259.333449  172.242583
#> [65,70)  -135.387122   23.459841  -40.30626 -265.443035 -563.523160  -49.325029
#> [70,75)   -18.983825  448.259376  229.21654  115.024731 -110.641818   83.609802
#> [75,80)  -152.892634  -49.423762 -188.59577 -270.861844   16.963918  352.580599
#> [80,85)   -48.257638  267.919469   79.58150    5.196754 -293.497802  182.069393
#> [85,111) -101.063705  368.548993 -280.20263  127.934643 -532.594448  481.242048
#>                 1986        1987        1988        1989
#> [0,1)      79.705691   99.151542   85.367064   69.428248
#> [1,5)    -105.091366 -115.415590 -129.460354 -138.825641
#> [5,10)     41.914908   33.575476   38.691475   30.243359
#> [10,15)    10.338312   -7.133098   -1.542695  -13.884174
#> [15,20)   -23.886561   -3.210832  -10.638742   33.086136
#> [20,25)    20.004227   12.136205   45.245598  -30.052031
#> [25,30)    -1.355760   13.195032    5.390816    3.529469
#> [30,35)   -37.413296    4.452748   15.879900  -14.021910
#> [35,40)    48.618805  -39.680138  -13.404218  -18.888900
#> [40,45)    -8.612828  -11.747284   88.870843  -22.333360
#> [45,50)    43.890729   -1.590522   42.702845  -51.434708
#> [50,55)   -20.439122   65.170062   13.745533    5.276019
#> [55,60)   -39.452825   42.595710   41.095334   30.546074
#> [60,65)  -129.016762 -137.516829   16.687265 -348.723251
#> [65,70)   138.412891  -20.085430  498.001264  330.485308
#> [70,75)    -7.701461  -66.245364  -17.867757 -562.157391
#> [75,80)  -153.427268  -79.797604  431.579425   25.343771
#> [80,85)   -63.772519 -351.827442  515.000615 -268.506225
#> [85,111) -135.741049 -337.161924  841.895060 -431.439798