| resolve_nlast | R Documentation |
A caller may state either the width of the last interval or the closing age of the distribution. This turns the second into the first.
resolve_nlast(x, nlast, omega)
x |
Vector containing the starting values of the input intervals/bins. |
nlast |
The width of the last interval. See |
omega |
The closing age of the distribution, an alternative to
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.