Skip to contents

Generic Plot for pclm Class

Usage

# S3 method for class 'pclm'
plot(x, xlab, ylab, ylim, type, lwd, col, legend, legend.position, ...)

Arguments

x

An object of class pclm

xlab

a label for the x axis, defaults to a description of x.

ylab

a label for the y axis, defaults to a description of y.

ylim

the y limits of the plot; see xlim for default and details.

type

1-character string giving the type of plot desired. The following values are possible, for details, see plot: "p" for points, "l" for lines, "b" for both points and lines, "c" for empty points joined by lines, "o" for overplotted points and lines, "s" and "S" for stair steps and "h" for histogram-like vertical lines. Finally, "n" does not produce any points or lines. Default: "l".

lwd

Line width, a positive number, defaulting to 2.

col

Three colors to be used in the plot for observed values, fitted values and confidence intervals, in that order. The histogram default is c("gold2", 2, 4); with an offset, which puts the plot on a log scale, it is c(1, 2, 4).

legend

Labels for the legend. With three colors the default is c("Input values", "Fitted values", "Conf. intervals").

legend.position

Legend position, or the x and y co-ordinates to be used to position the legend. The default is chosen from the data: if the first few bins are taller than the last few the legend goes top right, and top left otherwise, which keeps it off the peak. The rate plot always defaults to top left.

...

other graphical parameters (see par for more details).

See also

Examples

# See complete examples in pclm help page